@@ -424,8 +424,8 @@ setMethod(f="extractManipDataX", signature=c("sdcMicroObj"), definition=function
   }
 
   if (randomizeRecords!="no") {
-    hhId <- get.sdcMicroObj(obj, "hhId")
-    if (is.null(hhId) | randomizeRecords=="simple") {
+    hhid <- get.sdcMicroObj(obj, "hhId")
+    if (is.null(hhid) | randomizeRecords=="simple") {
       # just simple randomization
       o <- o[sample(1:nrow(o)),]
     } else {
