@@ -8,6 +8,18 @@ has_numkeyvars <- reactive({
 })
 
 # UI-output for top/bottom-coding of numerical variables
+output$ui_topbotcoding_num_header <- renderUI({
+  helptxt <- "Here you can recode all values in a variable below (bottom coding) or above (top coding) a certain threshold. These values are replaced"
+  helptxt <- paste(helptxt, "with the specified replacement value. The boxplot below shows the distribution of the data before top/bottom coding. ")
+  helptxt <- paste(helptxt, "The bottom of the box is the 25th percentile and the top of the box the 75th percentile. The bar in the boxplot is the median. ")
+  helptxt <- paste(helptxt, "The length of the whiskers is 1.5 times the interquartile range (IQR), unless the smallest/largest obeservation is closer to the box. Any value below/above the whiskers is indicated as outlier.")
+  out <- fluidRow(
+    column(12, h3("Apply top/bottom coding"), offset = 0, class = "wb-header"),
+    column(12, p(helptxt), offset = 0, class = "wb-header-hint")
+  )
+  out
+})
+
 output$ui_topbotcoding_num <- renderUI({
   output$ui_topbot_plot_num <- renderPlot({
     req(input$sel_topbot_var_num)
@@ -32,12 +44,12 @@ output$ui_topbotcoding_num <- renderUI({
     txt_tooltip1 <- "In case of top, all values above the threshold are replaced, in the case of bottom, all values below the threshold are replaced."
     txt_tooltip2 <- "All values below (bottom) or above (top) this threshold are replaced with the replacement value."
     txt_tooltip3 <- "The replacement value is the value that replaces all the values below (bottom) or above (top) the specified threshold. Often the replacement value is the same as the threshold value."
-    sel_var <- selectInput("sel_topbot_var_num", choices=numVars(), selected=obj$inp_sel_topbot_var_num, multiple=FALSE, label=h5("Select variable"), width="75%")
+    sel_var <- selectInput("sel_topbot_var_num", choices=numVars(), selected=obj$inp_sel_topbot_var_num, multiple=FALSE, label=p("Select variable"), width="75%")
     sel_kind <- radioButtons("sel_topbot_kind_num", choices=c("top","bottom"),
-      label=h5("Apply top/bottom coding?", tipify(icon("question"), title=txt_tooltip1, placement="top")), inline=TRUE)
-    txt_val <- textInput("num_topbot_val_num", label=h5("Threshold value", tipify(icon("question"), title=txt_tooltip2, placement="top")),
+      label=p("Apply top/bottom coding?", tipify(icon("info-circle"), title=txt_tooltip1, placement="top")), inline=TRUE)
+    txt_val <- textInput("num_topbot_val_num", label=p("Set threshold value", tipify(icon("info-circle"), title=txt_tooltip2, placement="top")),
       placeholder="Please enter a number", width="75%")
-    txt_replace <- textInput("num_topbot_replacement_num", label=h5("Replacement Value", tipify(icon("question"), title=txt_tooltip3, placement="top")),
+    txt_replace <- textInput("num_topbot_replacement_num", label=p("Set replacement value", tipify(icon("info-circle"), title=txt_tooltip3, placement="top")),
       placeholder="Please enter a number", width="75%")
     out <- fluidRow(column(6, sel_var, align="center"), column(6, sel_kind, align="center"))
     out <- list(out, fluidRow(column(6, txt_val, align="center"), column(6, txt_replace, align="center")))
@@ -82,15 +94,7 @@ output$ui_topbotcoding_num <- renderUI({
     }
   })
 
-  helptxt <- "Here you can recode all values in a variable below (bottom coding) or above (top coding) a certain threshold. These values are replaced"
-  helptxt <- paste(helptxt, "with the specified replacement value. The boxplot below shows the distribution of the data before top/bottom coding. ")
-  helptxt <- paste(helptxt, "The bottom of the box is the 25th percentile and the top of the box the 75th percentile. The bar in the boxplot is the median. ")
-  helptxt <- paste(helptxt, "The length of the whiskers is 1.5 times the interquartile range (IQR), unless the smallest/largest obeservation is closer to the box. Any value below/above the whiskers is indicated as outlier.")
-  out <- fluidRow(
-    column(12, h4("Apply top/bottom coding", align="center")),
-    column(12, p(helptxt), align="center")
-  )
-  out <- list(out, uiOutput("ui_topbot_params_num"))
+  out <- uiOutput("ui_topbot_params_num")
   out <- list(out, uiOutput("ui_topbot_btn_num"))
   out <- list(out, fluidRow(
     column(12, plotOutput("ui_topbot_plot_num"))
@@ -99,6 +103,13 @@ output$ui_topbotcoding_num <- renderUI({
 })
 
 # GUI-output for microaggregation()
+output$ui_microaggregation_header <- renderUI({
+  out <- fluidRow(
+    column(12, h4("Microaggregation for numerical variables"), offset = 0, class = "wb-header"),
+    column(12, p("Many different algorithms to microaggregate numeric key variables can be applied here. The most important
+                 parameter is the",code("aggregation level"), "because it specifies how many observations are grouped together before replacing actual values with some kind of aggregate."), offset = 0, class = "wb-header-hint"))
+  out
+})
 output$ui_microaggregation <- renderUI({
   # returns possible methods for microaggregation
   choices_aggmethods <- reactive({
@@ -128,15 +139,15 @@ output$ui_microaggregation <- renderUI({
     txt_clnrcl <- "Specifies the number of clusters generated by the clustering algorithm"
 
     rb_clustermethod <- radioButtons("rb_microagg_clustermethod",
-      label=h5("Clustermethod", tipify(icon("question"), title=txt_clmethod, placement="top")),
+      label=p("Clustermethod", tipify(icon("info-circle"), title=txt_clmethod, placement="top")),
       choices=c("clara","pam","kmeans","cmeans","bclust"), width="100%", selected=input$rb_microagg_clustermethod, inline=TRUE)
 
     rb_transf <- radioButtons("rb_microagg_transf",
-      label=h5("Transformation", tipify(icon("question"), title=txt_cltransf, placement="top")),
+      label=p("Transformation", tipify(icon("info-circle"), title=txt_cltransf, placement="top")),
       choices=c("none","log","boxcox"), width="100%", selected=input$rb_microagg_transf, inline=TRUE)
 
     sl_nc <- isolate(sliderInput("sl_microagg_nc",
-      label=h5("Number of clusters", tipify(icon("question"), title=txt_clnrcl, placement="top")),
+      label=p("Number of clusters", tipify(icon("info-circle"), title=txt_clnrcl, placement="top")),
       min=1, max=15, step=1, value=3, width="100%"))
 
     return(fluidRow(
@@ -148,14 +159,14 @@ output$ui_microaggregation <- renderUI({
   output$ui_microagg_strata <- renderUI({
     txt_tooltip <- "By default microaggregation is applied on the complete dataset. To apply the algorithm within strata, select a variable for stratification. The algorithm is then applied within the strata defined by the factor levels of that variable."
     selectInput("sel_microagg_strata",
-      label=h5("Apply microaggregation in groups (stratification)?", tipify(icon("question"), title=txt_tooltip, placement="top")),
+      label=p("Apply microaggregation in groups (stratification)?", tipify(icon("info-circle"), title=txt_tooltip, placement="top")),
       choices=c("no stratification", poss_strataVarP()), multiple=FALSE, width="100%", selected=input$sel_microagg_strata)
   })
   output$ui_microagg_use_cluster <- renderUI({
     txt_tooltip <- "Cluster-based methods consists of two steps: first creating cluster and subsequently applying microaggregation methods within clusters. Several clustering methods can be chosen as well as parameters for these methods."
     txt_tooltip <- paste0(txt_tooltip, "Clustering observations before applying microaggregation might be useful since the selected microaggregation algorithm is applied within clusters with a higher degree of homogeneity possibly resulting in lower levels of information loss.")
     radioButtons("rb_microagg_cluster",
-      label=h5("Use a cluster-based method?", tipify(icon("question"), title=txt_tooltip, placement="bottom")),
+      label=p("Use a cluster-based method?", tipify(icon("info-circle"), title=txt_tooltip, placement="bottom")),
       choices=c("No","Yes"), selected=input$rb_microagg_cluster, inline=TRUE, width="100%")
   })
   output$ui_microagg_method <- renderUI({
@@ -176,24 +187,24 @@ output$ui_microaggregation <- renderUI({
     txtClus <- paste(txtClus, "<strong>clustpppca</strong> - see pppca, applied for within each cluster<br />")
     if (input$rb_microagg_cluster=="No") {
       sel_method <- selectInput("sel_microagg_method",
-        label=h5("Select the method", tipify(icon("question"), title=txt, placement="bottom")),
+        label=p("Select the method", tipify(icon("info-circle"), title=txt, placement="bottom")),
         choices=choices_aggmethods(), selected=input$sel_microagg_method, width="100%")
     } else {
       sel_method <- selectInput("sel_microagg_method",
-        label=h5("Select the method", tipify(icon("question"), title=txtClus, placement="bottom")),
+        label=p("Select the method", tipify(icon("info-circle"), title=txtClus, placement="bottom")),
         choices=choices_aggmethods(), selected=input$sel_microagg_method, width="100%")
     }
   })
   output$ui_microagg_vars <- renderUI({
     txt_tooltip <- "Select numeric key variables for microaggregation. If no variables are selected, microaggregation is applied to all numeric key variables. If microaggregation is applied simultaneously to several variables, the results are different as the relationship between the variables is used."
     selectInput("sel_microagg_v", choices=possvars_numericmethods(),
-      label=h5("Select variables for microaggregation", tipify(icon("question"), title=txt_tooltip, placement="top")),
+      label=p("Select variables for microaggregation", tipify(icon("info-circle"), title=txt_tooltip, placement="top")),
       selected=input$sel_microagg_v, width="100%", multiple=TRUE)
   })
   output$ui_microagg_agglevel <- renderUI({
     txt_tooltip <- "Specifies the group size"
     sliderInput("sl_microagg_aggr",
-      label=h5("Aggregation-level", tipify(icon("question"), title=txt_tooltip, placement="top")),
+      label=p("Aggregation-level", tipify(icon("info-circle"), title=txt_tooltip, placement="top")),
       min=1, max=15, step=1, value=3, width="100%")
   })
   output$ui_microagg_aggmeasures <- renderUI({
@@ -203,28 +214,23 @@ output$ui_microaggregation <- renderUI({
     txt_tooltip <- paste(txt_tooltip, "<strong>trim</strong> - trimmed mean, specify trimming percentage <br />")
     txt_tooltip <- paste(txt_tooltip, "<strong>onestep</strong> - for each group, values further than 2.018843 times the median absolute deviation from the group median are replaced by the extreme values of this interval and subsequently the group mean is computed and used as replacement value <br />")
     radioButtons("sl_microagg_measure",
-      label=h5("Aggregation statistics", tipify(icon("question"), title=txt_tooltip, placement="top")),
+      label=p("Aggregation statistics", tipify(icon("info-circle"), title=txt_tooltip, placement="top")),
       choices=c("mean", "median", "trim", "onestep"), width="100%", selected=input$sl_microagg_measure, inline=TRUE)
   })
   output$ui_microagg_trim <- renderUI({
     txt_tooltip <- "Sets the trimming percentage if the aggregation statistic is trim. For other methods, this is ignored."
     sliderInput("sl_microagg_trim",
-      label=h5("Trimming-percentage", tipify(icon("question"), title=txt_tooltip, placement="top")),
+      label=p("Trimming-percentage", tipify(icon("info-circle"), title=txt_tooltip, placement="top")),
       min=0, max=0.5, step=0.01, value=0, width="100%")
   })
   output$ui_microagg_varsort <- renderUI({
     txt_tooltip <- "Select sorting variable for method ‘simple’ for sorting the records."
     sel_varsort <- selectInput("sel_microagg_varsort",
-      label=h5("Select variable for sorting", tipify(icon("question"), title=txt_tooltip, placement="top")),
+      label=p("Select variable for sorting", tipify(icon("info-circle"), title=txt_tooltip, placement="top")),
       choices=get_allNumericVars_name(), selected=input$sel_microagg_varsort, width="100%")
   })
 
-  out <- fluidRow(
-    column(12, h4("Microaggregation for numerical variables", align="center")),
-    column(12, p("Many different algorithms to microaggregate numeric key variables can be applied here. The most important
-      parameter is the",code("aggregation level"), "because it specifies how many observations are grouped together before replacing actual values with some kind of aggregate.", align="center")))
-
-  out <- list(out, fluidRow(
+  out <- list(fluidRow(
     column(4, uiOutput("ui_microagg_use_cluster"), align="center"),
     column(4, uiOutput("ui_microagg_method"), align="center"),
     column(4, uiOutput("ui_microagg_strata"), align="center")
@@ -263,6 +269,12 @@ output$ui_microaggregation <- renderUI({
 })
 
 # GUI-output for addNoise()
+output$ui_noise_header <- renderUI({
+  out <- fluidRow(
+    column(12, h4("Adding Stochastic Noise"), offset = 0, class = "wb-header"),
+    column(12, p("Here you can use various methods to add noise in order to perturb continuous variables. Note: stochastic noise is a probabilistic method and the results differ depending on the current seed for the random number generator."), offset = 0, class = "wb-header-hint"))
+  out
+})
 output$ui_noise <- renderUI({
   # returns possible methods for addNoise()
   # 'correlated' needs at least two columns=variables
@@ -289,27 +301,27 @@ output$ui_noise <- renderUI({
     req(input$sel_noise_method)
     if (input$sel_noise_method=="correlated2") {
       txt_tooltip <- "Delta is the parameter that determines the level of noise. The larger delta, the higher the noise level. Please refer to the literature for a more detailed description of the effect of delta."
-      lab <- h5("Amount of noise (parameter 'delta')", tipify(icon("question"), title=txt_tooltip, placement="top"))
+      lab <- p("Set amount of noise (parameter 'delta')", tipify(icon("info-circle"), title=txt_tooltip, placement="top"))
       par <- c(value=0.1, min=0.1, max=2, step=0.01)
     } else if (input$sel_noise_method=="ROMM") {
       txt_tooltip <- 'Parameter "p" is the multiplication factor for the method ROMM and corresponds to the magnitude of the perturbation. The value zero leads to no changes and the default value 0.001 to virtually no changes.'
-      lab <- h5("Amount of noise (parameter 'p')", tipify(icon("question"), title=txt_tooltip, placement="top"))
+      lab <- p("Set amount of noise (parameter 'p')", tipify(icon("info-circle"), title=txt_tooltip, placement="top"))
       par <- c(value=0.001, min=0.001, max=0.3, step=0.001)
     } else if (input$sel_noise_method=="correlated"){
       txt_tooltip <- "The added noise is proportional to the variance in the data. The specified amount of noise is the multiplier for the covariance matrix of the noise. For example, for the default value 150, the covariance matrix of the noise is 1.5 times the covariance matrix of the data. The added noise is generated from a multivariate normal distribution."
-      lab <- h5("Amount of noise (parameter 'noise')", tipify(icon("question"), title=txt_tooltip, placement="top"))
+      lab <- p("Set amount of noise (parameter 'noise')", tipify(icon("info-circle"), title=txt_tooltip, placement="top"))
       par <- c(value=150, min=0, max=300, step=1)
     } else if (input$sel_noise_method=="restr"){
       txt_tooltip <- "The size of the noise depends on the parameter noise and the sample size. The higher this parameter, the larger the noise."
-      lab <- h5("Amount of noise (parameter 'noise')", tipify(icon("question"), title=txt_tooltip, placement="top"))
+      lab <- p("Set amount of noise (parameter 'noise')", tipify(icon("info-circle"), title=txt_tooltip, placement="top"))
       par <- c(value=150, min=0, max=300, step=1)
     } else if (input$sel_noise_method=="outdect"){
       txt_tooltip <- "The added noise is proportional to the variance in the data. The specified amount of noise is the multiplier for the standard deviation of the noise. For example, for the default value 150, the standard deviation of the noise is 1.5 times the standard deviation in the data."
-      lab <- h5("Amount of noise (parameter 'noise')", tipify(icon("question"), title=txt_tooltip, placement="top"))
+      lab <- p("Set amount of noise (parameter 'noise')", tipify(icon("info-circle"), title=txt_tooltip, placement="top"))
       par <- c(value=150, min=0, max=300, step=1)
     } else {
       txt_tooltip <- "The added noise is proportional to the variance in the data. The specified amount of noise is the multiplier for the standard deviation of the noise. For example, for the default value 150, the standard deviation of the noise is 1.5 times the standard deviation in the data. The added noise is generated from a univariate normal distribution."
-      lab <- h5("Amount of noise (parameter 'noise')", tipify(icon("question"), title=txt_tooltip, placement="top"))
+      lab <- p("Set amount of noise (parameter 'noise')", tipify(icon("info-circle"), title=txt_tooltip, placement="top"))
       par <- c(value=150, min=0, max=300, step=1)
     }
     sliderInput("sl_noise_noise", label=lab, min=par["min"], max=par["max"], step=par["step"], value=par["value"], width="100%")
@@ -325,7 +337,7 @@ output$ui_noise <- renderUI({
     txt_tooltip <- paste0(txt_tooltip, "<strong>outdect</strong> - adds noise only to outliers in the data. The outliers are identified with univariate and robust multivariate procedures based on a robust Mahalanobis distance calculated by the MCD estimator.<br />")
     txt_tooltip <- paste0(txt_tooltip, "<strong>correlated</strong> - adds noise and preserves the covariance matrix")
     selectInput("sel_noise_method",
-      label=h5("Select the algorithm", tipify(icon("question"), title=txt_tooltip, placement="bottom")),
+      label=p("Select the algorithm", tipify(icon("info-circle"), title=txt_tooltip, placement="bottom")),
       choices=choices_noise(), selected=input$sel_noise_method, width="100%")
   })
 
@@ -333,7 +345,7 @@ output$ui_noise <- renderUI({
   output$ui_noise_vars <- renderUI({
     txt_tooltip <- 'Note that for some methods, the results are different if noise is added to single variables or to groups of variables. An example is the method "correlated2", which preserves the covariance matrix of the data.'
     selectInput("sel_noise_v", choices=get_numVars_names(),
-      label=h5("Select variables", tipify(icon("question"), title=txt_tooltip, placement="bottom")),
+      label=p("Select variables", tipify(icon("info-circle"), title=txt_tooltip, placement="bottom")),
       width="75%", multiple=TRUE)
   })
 
@@ -347,12 +359,8 @@ output$ui_noise <- renderUI({
   })
 
   out <- fluidRow(
-    column(12, h4("Adding Stochastic Noise", align="center")),
-    column(12, p("Here you can use various methods to add noise in order to perturb continuous variables. Note: stochastic noise is a probabilistic method and the results differ depending on the current seed for the random number generator.", align="center")))
-
-  out <- list(out, fluidRow(
     column(6, uiOutput("ui_noise_vars"), align="center"),
-    column(6, uiOutput("ui_noise_method"), align="center")))
+    column(6, uiOutput("ui_noise_method"), align="center"))
 
   out <- list(out, fluidRow(column(12, uiOutput("ui_noise_slider"), align="center")))
   out <- list(out, fluidRow(column(12, uiOutput("ui_noise_btn"), align="center")))
@@ -365,6 +373,14 @@ output$ui_shuffling <- renderUI({
 })
 
 # GUI-output for rankSwap()
+output$ui_rankswap_header <- renderUI({
+  out <- fluidRow(
+    column(12, h4("Rank Swapping"), offset = 0, class = "wb-header"),
+    column(12, p("This is a method to be used on numeric or ordinal variables. The idea is to",tags$i("swap"),"values within a range
+                 so that correlation structure of original variables is preserved and some perturbation is applied. Note: rank swapping is a probabilistic method
+                 and therefore the results differ depending on the current seed for the random number generator."), offset = 0, class = "wb-header-hint"))
+  out
+})
 output$ui_rankswap <- renderUI({
   if (!has_numkeyvars()) {
     return(fluidRow(
@@ -385,19 +401,19 @@ output$ui_rankswap <- renderUI({
   output$ui_rankswap_vars <- renderUI({
     txt_tooltip <- "Note that the results are different if rank swapping is applied to single variables or to groups of variables, since the covariance matrix is preserved."
     selectInput("sel_rankswap_v",
-      choices=possvars_numericmethods(), label=h5("Select variables", tipify(icon("question"), title=txt_tooltip, placement="top")),
+      choices=possvars_numericmethods(), label=p("Select variables", tipify(icon("info-circle"), title=txt_tooltip, placement="top")),
       width="100%", multiple=TRUE)
   })
   output$sl_rankswap_top <- renderUI({
     txt_tooltip <- "The highest values can be top coded before applying rank-swapping in order to protect outliers. This parameter specifies the number of values to be top coded as percentage of the sample size. By default no values are top coded."
     sliderInput("sl_rankswap_top",
-      label=h5("Percentage of highest values that are grouped together before rank swapping", tipify(icon("question"), title=txt_tooltip, placement="top")),
+      label=p("Set percentage of highest values that are grouped together before rank swapping", tipify(icon("info-circle"), title=txt_tooltip, placement="top")),
       min=0, max=25, step=1, value=0, width="100%")
   })
   output$sl_rankswap_bot <- renderUI({
     txt_tooltip <- "The lowest values can be bottom coded before applying rank-swapping in order to protect outliers. This parameter specifies the number of values to be bottom coded as percentage of the sample size. By default no values are bottom coded."
     sliderInput("sl_rankswap_bot",
-      label=h5("Percentage of lowest values that are grouped together before rank swapping", tipify(icon("question"), title=txt_tooltip, placement="top")),
+      label=p("Set percentage of lowest values that are grouped together before rank swapping", tipify(icon("info-circle"), title=txt_tooltip, placement="top")),
       min=0, max=25, step=1, value=0, width="100%")
 
   })
@@ -406,33 +422,27 @@ output$ui_rankswap <- renderUI({
     txt_tooltip <- paste0(txt_tooltip, "The absolute difference between the variable mean before and swapping (abs(X_1 - X_2), where X_1 is the (subset) sample mean before swapping ")
     txt_tooltip <- paste0(txt_tooltip, "and X_2 is the (subset) sample mean after swapping) is kept smaller than or equal to 2 * K_0 * X_1 / sqrt(N_S), where N_S is the sample size of the subset under consideration. Therefore, larger values of K_0 allow larger deviations.")
     sliderInput("sl_rankswap_k0",
-      label=h5("Subset-mean preservation factor", tipify(icon("question"), title=txt_tooltip, placement="bottom")),
+      label=p("Set subset-mean preservation factor", tipify(icon("info-circle"), title=txt_tooltip, placement="bottom")),
       min=0, max=1, step=0.01, value=0, width="100%")
   })
   output$sl_rankswap_r0 <- renderUI({
     txt_tooltip <- "The algorithm preserves the correlation between variables within a certain range based on the specified multivariate preservation factor R_0, such that R_1/R_2 > R_0 where R_1 is the correlation coefficient of the two variables after swapping, "
     txt_tooltip <- paste0(txt_tooltip, "and R_2 is the correlation coefficient of the two variables before swapping.")
     sliderInput("sl_rankswap_r0",
-      label=h5("Multivariate preservation factor", tipify(icon("question"), title=txt_tooltip, placement="top")),
+      label=p("Set multivariate preservation factor", tipify(icon("info-circle"), title=txt_tooltip, placement="top")),
       min=0, max=1, step=0.01, value=0.95, width="100%")
   })
   output$sl_rankswap_p <- renderUI({
     txt_tooltip <- "This parameter (P) describes the size of the rank range as percentage of the total sample size. So two records are eligible for swapping if their ranks, i and j respectively, satisfy abs(i-j) < P*N/100, where N is the total sample size."
     sliderInput("sl_rankswap_p",
-      label=h5("Rank range as percentage of total sample size.", tipify(icon("question"), title=txt_tooltip, placement="top")),
+      label=p("Set rank range as percentage of total sample size.", tipify(icon("info-circle"), title=txt_tooltip, placement="top")),
       min=0, max=100, step=1, value=0, width="100%")
   })
 
   out <- fluidRow(
-    column(12, h4("Rank Swapping"), align="center"),
-    column(12, p("This is a method to be used on numeric or ordinal variables. The idea is to",tags$i("swap"),"values within a range
-      so that correlation structure of original variables is preserved and some perturbation is applied. Note: rank swapping is a probabilistic method
-      and therefore the results differ depending on the current seed for the random number generator."), align="center"))
-
-  out <- list(out, fluidRow(
     column(4, uiOutput("ui_rankswap_vars"), align="center"),
     column(4, uiOutput("sl_rankswap_bot"), align="center"),
-    column(4, uiOutput("sl_rankswap_top"), align="center")))
+    column(4, uiOutput("sl_rankswap_top"), align="center"))
 
   out <- list(out, fluidRow(
     column(4, uiOutput("sl_rankswap_k0"), align="center"),
