@@ -1,6 +1,9 @@
 library(shiny)
 
 shinyServer(function(session, input, output) {
+  wd <- setwd(getShinyOption(".appDir", getwd()))
+  on.exit(setwd(wd))
+  
   for (file in list.files("controllers")) {
     source(file.path("controllers", file), local=TRUE)
   }
